@@ -24,6 +24,7 @@ from .type_defs import (
     ClaimDevicesByClaimCodeResponseTypeDef,
     DescribeDeviceResponseTypeDef,
     DeviceMethodTypeDef,
+    EmptyResponseMetadataTypeDef,
     FinalizeDeviceClaimResponseTypeDef,
     GetDeviceMethodsResponseTypeDef,
     InitiateDeviceClaimResponseTypeDef,
@@ -98,6 +99,14 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client/#claim_devices_by_claim_code)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client/#close)
+        """
+
     def describe_device(self, *, DeviceId: str) -> DescribeDeviceResponseTypeDef:
         """
         Given a device ID, returns a DescribeDeviceResponse object describing the
@@ -151,7 +160,7 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         self,
         *,
         DeviceId: str,
-        DeviceMethod: "DeviceMethodTypeDef" = ...,
+        DeviceMethod: DeviceMethodTypeDef = ...,
         DeviceMethodParameters: str = ...
     ) -> InvokeDeviceMethodResponseTypeDef:
         """
@@ -197,7 +206,9 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client/#list_tags_for_resource)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> None:
+    def tag_resource(
+        self, *, ResourceArn: str, Tags: Mapping[str, str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Adds or updates the tags associated with the resource ARN.
 
@@ -213,7 +224,9 @@ class IoT1ClickDevicesServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot1click_devices/client/#unclaim_device)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> None:
+    def untag_resource(
+        self, *, ResourceArn: str, TagKeys: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Using tag keys, deletes the tags (key/value pairs) associated with the specified
         resource ARN.
